==> lxqt-runner-0.14.0.tar.xz: lxqt-runner-0.14.0/translations/lxqt-runner_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Definições do Runner</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Posição:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Mostrar:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Mostrar histórico primeiro</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Guardar/mostrar histórico</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Noto&lt;/b&gt;: o tamanho dos widgets do nível superior está restringido a 2/3 da altura e da largura da área de trabalho.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Mostrar lista com:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> itens</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Atalho:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Margem superior do ecrã</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Centro do ecrã</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Focused screen</source>
        <translation>Ecrã em foco</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="72"/>
        <source>Always on screen %1</source>
        <translation>Sempre no ecrã %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="81"/>
        <source>Reset</source>
        <translation>Repor</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Lançador de aplicações </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="94"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="98"/>
        <source>Clear History</source>
        <translation>Limpar histórico</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="351"/>
        <source>Show/hide runner dialog</source>
        <translation>Mostrar/ocultar caixa de diálogo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="824"/>
        <source>Mathematics</source>
        <translation>Matemática</translation>
    </message>
</context>
</TS>

==> lxqt-runner_0.14.1.orig.tar.xz: lxqt-runner-0.14.1/translations/lxqt-runner_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Definições do Runner</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Posição:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Mostrar:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Mostrar histórico primeiro</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Guardar/mostrar histórico</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Nota&lt;/b&gt;: o tamanho dos widgets de nível superior está restringido a 2/3 da altura e da largura da área de trabalho.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Mostrar lista com:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> itens</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Atalho:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Margem superior do ecrã</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Centro do ecrã</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Focused screen</source>
        <translation>Ecrã em foco</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="72"/>
        <source>Always on screen %1</source>
        <translation>Sempre no ecrã %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="81"/>
        <source>Reset</source>
        <translation>Repor</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Lançador de aplicações </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="94"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="98"/>
        <source>Clear History</source>
        <translation>Limpar histórico</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="351"/>
        <source>Show/hide runner dialog</source>
        <translation>Mostrar/ocultar caixa de diálogo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="824"/>
        <source>Mathematics</source>
        <translation>Matemática</translation>
    </message>
</context>
</TS>
